==> haskell-gi-cairo-connector-0.1.1-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-Hzv5rvTcLmrK53HvgvQjqa
key:                  gi-cairo-connector-0.1.1-Hzv5rvTcLmrK53HvgvQjqa
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  1aab16a152fb9e79950d924dc9d5dc4d
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.0.2/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-Hzv5rvTcLmrK53HvgvQjqa
depends:
    base-4.15.1.0 gi-cairo-1.0.29-2mG4Kon7c9lFHiQTL0gVsY
    gi-cairo-render-0.1.2-Fpp8LT1aLVtLigW6QK0HeB
    haskell-gi-base-0.26.3-F9RrvzwFZ6b9FvkaVvE8dw mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-cairo-connector-0.1.1-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-66PFVxJTh5cF1jbYoktyAT
key:                  gi-cairo-connector-0.1.1-66PFVxJTh5cF1jbYoktyAT
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  aada9384a2fb0e462fc99b6ad7b05f8a
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.0.2/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-66PFVxJTh5cF1jbYoktyAT
depends:
    base-4.15.1.0 gi-cairo-1.0.29-ANIpCnVUozmJHiOpGU74Te
    gi-cairo-render-0.1.2-6m1vTgdCNrhCzoA7koRjOR
    haskell-gi-base-0.26.4-CE4lu6s01NFEl72cOqded7 mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
